from setuptools import setup

setup(
    name='RPICommLink',
    version='1.0.1',
    author='adixu',
    author_email='adixu7@gmail.com',
    description='A library for communication on Raspberry Pi',
    packages=['RPICommLink'],
    install_requires=[],
)
